      subroutine dustmat(p1,p2,p3,p4,cost,cost2,pi,isc)

c				    a.d. code october 25, 1989
c				revised baw apr 10, 1990
c	**********************************************************************
c
c	this program calculates the elements of the phase matrix for a
c	simple representation of the mrn dust mixture using the algorithms
c	for the ultraviolet region due to richard l. white ap.j. 229, 954,
c	1979.
c
c	***********************************************************************
c
c	    cost = cos(angle) of scattering (i.e. angle between incident 
c	        photon and scattered photon)
c	    g = mean value of cosine of scattering angle (henyey-greenstein)
c	    pl = peak linear polarization
c	    pc = peak value of linear to circular conversion
c	    sc = asymmetry of the circular polarization.
c	    p1 = intensity phase function
c	    p2 = polarization function
c	    p3 = skew polarization
c	    p4 = circular polarization
c
c	    the scattering matrix for (i,q,u,v) is of the form
c
c		 p1    p2    0	  0
c		 p2    p1    0	  0
c		 0     0     p3  -p4
c		 0     0     p4   p3
c
c	**********************************************************************
c history:
c 01/01/02 (baw):  reduce peak of cornette & shanks function by factor of 2
c 98/06/06 (mjw):  remove call to ACOSD
	implicit none

	real*8 pi, p1,p2,p3,p4,cost,cost2,f,f2,c,phi,pol2
	real*8 check
	integer isc
	character*20 routine

	include 'mrncoef.txt'

	routine='dustmat'
c     
c     p1 = (1 - g(isc)**2)/(1+g(isc)**2-2*g(isc)*cost)**1.5
c     modified Cornette & Shanks function---make sure peak is known
c     normalization is 1, same as h-g.  integral is 2.*2pi=4*pi
c     p1 = (1.-g(isc)**2)/(2.+g(isc)**2)*(1+cost2)/
c     1       (1.+g(isc)**2-2.*g(isc)*cost)**1.5
c     huh?  it's 1.5, I just tested it in IDL.  12/12/03 baw
        p1 = 1.5*(1.-g(isc)**2)/(2.+g(isc)**2)*(1+cost2)/
     1       (1.+g(isc)**2-2.*g(isc)*cost)**1.5
	p2 = -pl(isc)*p1*(1-cost2)/(1+cost2)
	p3 = p1*2*cost/(1+cost2)
c     took out circular pol. from this routine, put it in only
c     for dust tables.
        p4 = 0.
c     NOTE*****:  putting in circular polarization can cause problems
c     if linear polarization is large.  It gives pol > I.  
c     it works fine for pl=0.5.
        
	return
	end

